@@ -1,4 +1,4 @@
-use mikrotik::{Client, ClientError};
+use mikrotik::{ip::dhcp_client::DhcpClientInput, Client, ClientError};
 use reqwest::Url;
 
 #[tokio::test]
@@ -110,3 +110,75 @@ async fn get_address() -> Result<(), ClientError> {
 
     Ok(())
 }
+
+#[tokio::test]
+async fn list_dhcp_client() -> Result<(), ClientError> {
+    let base = Url::parse("https://10.0.10.1")?;
+    let mut client = Client::new(base, "admin".to_string(), "ifd783far".to_string(), true)
+        .expect("error in creating client");
+
+    let response = mikrotik::ip::dhcp_client::list(&mut client).await?;
+
+    println!("{:?}", response);
+
+    Ok(())
+}
+
+#[tokio::test]
+async fn get_dhcp_client() -> Result<(), ClientError> {
+    let base = Url::parse("https://10.0.10.1")?;
+    let mut client = Client::new(base, "admin".to_string(), "ifd783far".to_string(), true)
+        .expect("error in creating client");
+
+    let response = mikrotik::ip::dhcp_client::list(&mut client).await?;
+
+    let response = mikrotik::ip::dhcp_client::get(&mut client, &response[0].id).await?;
+
+    println!("{:?}", response);
+
+    Ok(())
+}
+
+#[tokio::test]
+async fn renew_dhcp_lease() -> Result<(), ClientError> {
+    let base = Url::parse("https://10.0.10.1")?;
+    let mut client = Client::new(base, "admin".to_string(), "ifd783far".to_string(), true)
+        .expect("error in creating client");
+
+    let response = mikrotik::ip::dhcp_client::list(&mut client).await?;
+
+    let response = mikrotik::ip::dhcp_client::renew(
+        &mut client,
+        DhcpClientInput {
+            numbers: response[0].id.clone(),
+        },
+    )
+    .await?;
+
+    println!("{:?}", response);
+
+    Ok(())
+}
+
+#[tokio::test]
+async fn release_dhcp_lease() -> Result<(), ClientError> {
+    let base = Url::parse("https://10.0.10.1")?;
+    let mut client = Client::new(base, "admin".to_string(), "ifd783far".to_string(), true)
+        .expect("error in creating client");
+
+    let response = mikrotik::ip::dhcp_client::list(&mut client).await?;
+
+    println!("{:?}", response);
+
+    let response = mikrotik::ip::dhcp_client::release(
+        &mut client,
+        DhcpClientInput {
+            numbers: response[0].id.clone(),
+        },
+    )
+    .await?;
+
+    println!("{:?}", response);
+
+    Ok(())
+}
